@@ -3,13 +3,14 @@ use promkit::{
     suggest::Suggest, text, text_editor,
 };
 
+#[derive(Clone)]
 pub struct Renderer {
     pub keymap: KeymapManager<Self>,
     pub query_editor_snapshot: Snapshot<text_editor::Renderer>,
     pub hint_message_snapshot: Snapshot<text::Renderer>,
     pub suggest: Suggest,
     pub suggest_snapshot: Snapshot<listbox::Renderer>,
-    pub json_bundle_snapshot: Snapshot<json::bundle::Renderer>,
+    pub json_snapshot: Snapshot<json::Renderer>,
 }
 
 impl_as_any!(Renderer);
@@ -21,7 +22,7 @@ impl promkit::Renderer for Renderer {
         panes.extend(self.query_editor_snapshot.create_panes(width));
         panes.extend(self.hint_message_snapshot.create_panes(width));
         panes.extend(self.suggest_snapshot.create_panes(width));
-        panes.extend(self.json_bundle_snapshot.create_panes(width));
+        panes.extend(self.json_snapshot.create_panes(width));
         panes
     }
 }
